@@ -1,5 +1,7 @@
 <?php
 
+# comment 
+
 $number1=123;
 $number2 = 123.45;
 
@@ -26,4 +28,9 @@ define( "ANOTHER_CONSTANT",	    "NJ, the garden state" );
 $hash5 = Array( 'constant'  => TEST_CONSTANT );
 $array5 = Array( 'test', ANOTHER_CONSTANT );
 
+$hash6 =  Array( 'foo' => 'bar', );
+$array6 = Array( 'foo', );
+
+# trailing comma
+
 ?>
